from typing import Dict, List, Union

Vector = List[float]
StringDictionary = Dict[str, str]
NumberDictionary = Dict[str, float]
OrderedDictionary = Dict[int, str]
NumType = Union[Vector, NumberDictionary, int, float, list]


# makes multiple instances of the object available.
class Meta(type):

    def __call__(
        self, 
        *args, 
        **kwargs,
        ) -> object:
        instance = super(Meta, self).__call__(*args, **kwargs)

        return instance

    def __init__(
        self, 
        name, 
        base, 
        attr,
        ) -> object:
        super(Meta, self).__init__(name, base, attr)



# imports relevant contents.
from vandal.plugins.metaclass import Meta
from vandal.plugins.types import (
    Vector,
    StringDictionary,
    NumberDictionary,
    OrderedDictionary,
    NumType,
)

# all relevant contents.
__all__ = [
    Vector,
    StringDictionary,
    NumberDictionary,
    OrderedDictionary,
    NumType,
]

# available types.
__types__ = [
    Vector,
    StringDictionary,
    NumberDictionary,
    OrderedDictionary,
    NumType,
]